@@ -45,14 +45,14 @@ sub parse_index {
   my $x1_dim = $x1->dim_as_array->values;
   my @indexs;
   my @x2_dim;
-
-  if (ref $_indexs[0] && $_indexs[0]->is_array && $_indexs[0]->is_logical && @{$_indexs[0]->dim->decompose_elements} > 1) {
+  
+  if (ref $_indexs[0] && $_indexs[0]->is_array && $_indexs[0]->is_logical && $_indexs[0]->dim->length_value > 1) {
     my $x2 = $_indexs[0];
     my $x2_dim_values = $x2->dim->values;
-    my $x2_elements = $x2->decompose_elements;
+    my $x2_values = $x2->values;
     my $poss = [];
-    for (my $i = 0; $i < @$x2_elements; $i++) {
-      next unless $x2_elements->[$i];
+    for (my $i = 0; $i < @$x2_values; $i++) {
+      next unless $x2_values->[$i];
       push @$poss, $i;
     }
     
@@ -110,9 +110,8 @@ sub parse_index {
       }
       elsif ($index->is_logical) {
         my $index_values_new = [];
-        my $index_elements = $index->decompose_elements;
         for (my $i = 0; $i < @{$index->values}; $i++) {
-          push @$index_values_new, $i + 1 if $index_elements->[$i];
+          push @$index_values_new, $i + 1 if $index_values->[$i];
         }
         $index = Rstats::Func::array($index_values_new);
       }
@@ -127,7 +126,7 @@ sub parse_index {
 
       push @indexs, $index;
 
-      my $count = $index->elements->length_value;
+      my $count = $index->vector->length_value;
       push @x2_dim, $count unless $count == 1 && $drop;
     }
     @x2_dim = (1) unless @x2_dim;
